==========
Change log
==========

1.3 (2018-08-03)
================

- Change license from ZPL to MIT.


1.2.post1 (2017-12-26)
======================

- Also release as wheel.


1.2 (2017-04-08)
================

- `install-addressbook` now prints a message before starting the download.

- `archive-addressbook` now prints a message before starting archiving.

1.1.1 (2017-01-07)
==================

- Prevent an error in `archive-addressbook` if the ``bz2`` module is not
  available.


1.1 (2017-01-07)
================

- Add ``make-current-addressbook`` script to ease usage of the `current`
  symlink in case of an error.


1.0 (2017-01-06)
================

- Initial release.
